@@ -46,6 +46,9 @@ def api_search(title: str) -> Dict[str,List[AnimeThemeAnime]]:
     """
     Requests a search from the api.
     """
+    if not title:
+        return None # an empty anime title
+    
     r = session.get(URL.format(title))
     if r.status_code == 200:
         return r.json()
@@ -73,12 +76,11 @@ def fetch_anime(title: str, alid: int, alsite: AnimeListSite) -> Optional[AnimeT
     May make an extra request before finding the right data.
     """
     for func in (remove_bracket,simplify_title):
-        new_title = func(title)
-        if title == new_title: continue
-        else: title = new_title
+        title = func(title)
         
         data = api_search(title)
-        if data is None: return None
+        if data is None: return None # internal error?
+        
         anime = verify_anime(data['anime'],alid,alsite)
         if anime is not None: return anime
     
@@ -139,7 +141,7 @@ def fetch_animethemes(animelist: List[AnimeListEntry], use_cache=True) -> List[A
     
     if animelist:
         with ThreadPoolExecutor(MAXWORKERS) as executor:
-            futures = [(executor.submit(fetch_anime, *al),al) for al in reversed(animelist)]
+            futures = [(executor.submit(fetch_anime, *al),al) for al in animelist][::-1]
             
             try:
                 while futures:
@@ -158,7 +160,7 @@ def fetch_animethemes(animelist: List[AnimeListEntry], use_cache=True) -> List[A
             except AnimeThemesTimeout as e:
                 logger.error(f'[error] {e.args[0]}')
             finally:
-                for future in futures: future[0].cancel()
+                for f in futures: f[0].cancel()
     
     animethemes = list(animethemes.values())
     if use_cache and animelist:
@@ -166,7 +168,7 @@ def fetch_animethemes(animelist: List[AnimeListEntry], use_cache=True) -> List[A
     
     if animelist:
         if logger.level <= logging.INFO: print()
-        logger.info(f"[get] Got {fetched+failed}/{total} entries{(f' ({failed} unavalible) ' if failed else ' ')}from animethemes.moe")
+        logger.info(f"[get] Got {fetched+failed}/{total} entries{(f' ({failed} unavalible) ' if failed else ' ')}from animethemes.moe in {m()}s")
     else:
         logger.info(f'[get] Loaded {len(animethemes)} cached entries from animethemes.moe')
     
